import {SecurityContext} from '../SecurityContext'
import {Inject, Injectable} from '../../di'
import {Session} from '../../http/session/Session'
import {Awaitable} from '../../util'

/**
 * Security context implementation that uses the session as storage.
 */
@Injectable()
export class SessionSecurityContext extends SecurityContext {
    @Inject()
    protected readonly session!: Session

    getCredentials(): Awaitable<Record<string, string>> {
        return {
            securityIdentifier: this.session.get('extollo.auth.securityIdentifier'),
        }
    }

    persist(): Awaitable<void> {
        this.session.set('extollo.auth.securityIdentifier', this.getUser()?.getIdentifier())
    }
}
